@@ -42,7 +42,7 @@ sub next {
 
 =head1 NAME
 
-I - Iterator
+C<I> - Iterator
 
 
 =head1 SYNOPSIS
@@ -59,7 +59,7 @@ I - Iterator
 
 =head1 DESCRIPTION
 
-I is a tiny iterator over an array reference. It tracks the current position
+C<I> is a tiny iterator over an array reference. It tracks the current position
 and returns items from the underlying array. Could be used when you are trying
 to mock iteration over ResultSet. See L<DBIx::Class>.
 
