@@ -116,7 +116,7 @@ sub diff { shift->delta_days( shift )->{ days } }
 
 =head1 NAME
 
-T - Stands for Time
+C<T> - Stands for Time
 
 This module mostly a handy wrapper around DateTime module.
 
@@ -125,12 +125,13 @@ This module mostly a handy wrapper around DateTime module.
 
   use T;
 
-  my $dt  =  T::new '2024-01-02 03:04:05';
+  my $dt  =  T::new '2024-01-02 03:04:05';           # 2024-01-02 03:04:05
   my $now =  T::now;
+  my $fmt =  T::fdy T::new '2024-01-02 03:04:05'     # 02.01.2024
   my $day =  T::tday $now;
-  my $ymd =  T::fymd $now, '@';  # 2024@01@02
+  my $ymd =  T::fymd $now, '@';                      # 2024@01@02
 
-  my $secs =  T::steady;
+  my $secs =  T::steady;                             # 429.376863203
 
 
 =head1 DESCRIPTION
@@ -156,8 +157,8 @@ T::new.
   my $dt =  T::new '2024-01-02 03:04:05';    # Parse string.
   my $dt =  T::new $value;
 
-Parse C<$value> into a L<DateTime> object. All objects assigned 'DateTime::Format::Pg'
-formatter and C<local> timezone. Parsing is done via 'DateTime::Format::Pg'.
+Parse C<$value> into a L<DateTime> object. All objects assigned L<DateTime::Format::Pg>
+formatter and C<local> timezone. Parsing is done via L<DateTime::Format::Pg>.
 
 
 =over 2
@@ -172,7 +173,7 @@ False value: return undef.
 
 =item *
 
-DateTime object: return it unchanged.
+DateTime object: return it unchanged. (Does it worth to force formatter and TZ?)
 
 =item *
 
@@ -215,7 +216,7 @@ High-resolution current time. See L<DateTime::HiRes> for details.
 
 =head2 now
 
-  my $dt =  T::now;
+  my $dt =  T::now;           # 2026-01-28 10:13:56-0500
 
 Current time. Synonym for C<DateTime::now> but additionally assigned C<local>
 timezone.
@@ -223,14 +224,15 @@ timezone.
 
 =head2 today
 
-  my $dt =  T::today;
+  my $dt =  T::today;         # 2027-01-21 00:00:00
 
 Current date (start of the day). Alias to C<DateTime-E<gt>today>.
 
 
 =head2 tmrw
 
-  my $dt =  T::tmrw $value;
+  my $dt =  T::tmrw           # 2027-01-22 00:00:00
+  my $dt =  T::tmrw $value;   # 2024-08-17 15:33:00 -> 2024-08-18 00:00
 
 Return "tomorrow" (C<$value> truncated to day, plus one day).
 
@@ -270,8 +272,8 @@ See C<DateTime-E<gt>add> for details.
 
 =head2 first_day
 
-  my $dt =  T::first_day $value;                 # 2027-05-15    -> 2027-05-01
-  my $dt =  T::first_day $value, $months_ahead;  # 2027-05-15, 3 -> 2027-08-01
+  my $dt =  T::first_day $value;                  # 2027-05-15    -> 2027-05-01
+  my $dt =  T::first_day $value, $months_ahead;   # 2027-05-15, 3 -> 2027-08-01
 
 Return the first day of the month for C<$value>. If C<$months_ahead> is
 provided, move forward by that many months.
@@ -289,10 +291,12 @@ L<Time::HiRes/time>.
 
   my $str =  T::fmt $format;
   my $str =  T::fmt $format, $value;
+  my $str =  T::fmt '%I:%M%P %j %U %a', '2025-12-31 23:00:00';   # 11:00pm 365 52 Wed
 
 Format a date using C<strftime>. C<$value> is passed through L</new>. See
-L<DateTime/strftime> for details. https://metacpan.org/pod/DateTime#strftime-Patterns
+L<DateTime/strftime-Patterns> for details.
 
+TODO? Should it be just C<T::f>?
 
 =head2 fymd
 
@@ -300,7 +304,7 @@ L<DateTime/strftime> for details. https://metacpan.org/pod/DateTime#strftime-Pat
   my $str =  T::fymd $value;
   my $str =  T::fymd $value, $sep;
 
-Format as YYYYE<lt>sepE<gt>MME<lt>sepE<gt>DD.
+Format as C<YYYYE<lt>sepE<gt>MME<lt>sepE<gt>DD>.
 
 
 =head2 fmdy
@@ -309,7 +313,7 @@ Format as YYYYE<lt>sepE<gt>MME<lt>sepE<gt>DD.
   my $str =  T::fmdy $value;
   my $str =  T::fmdy $value, $sep;
 
-Format as MME<lt>sepE<gt>DDE<lt>sepE<gt>YYYY.
+Format as C<MME<lt>sepE<gt>DDE<lt>sepE<gt>YYYY>.
 
 
 =head2 fdmy
